@@ -83,7 +83,12 @@ foreach ($USER->getArchives(false) as $container) { // no SYSINFO
     $BennoUser->addArchive($container);
 }
 
-$BennoUser->save();
+$sfx = '';
+if ($App->getConfig('ENFORCE_USERSUFFIX')) { 
+    // username suffix to separate users in multi domain setup
+    $sfx = $USER->getIdSuffix();
+}
+$BennoUser->save($sfx);
 
 $App->redirect('userList',array('MSG' => 'MSG_UPDATED'));
 ?>
