@@ -265,7 +265,8 @@ class Backend
             $maildata = $this->_curl_query($request_url,$query_string,$format);
         }
         catch (exception $e) {  // FS#1105
-            if ($e->getMessage() == 'ERR_REST_404') {
+            $error_msg = $e->getMessage();
+            if ($error_msg == 'ERR_REST_404') {
                 $base_url_fallback = $App->getConfig('BASE_URL_FALLBACK');
                 if ($base_url_fallback) {
                     $fallback_url = rtrim($base_url_fallback,'/').'/mail/';
@@ -276,6 +277,9 @@ class Backend
                     throw new Exception('ERR_REST_404');
                 }
             }
+            else {
+                throw new Exception('ERR_REQUEST');
+            }
         }
 
         return $maildata;
@@ -329,6 +333,12 @@ class Backend
             }
         }
 
+        // set proxy for cURL requests (null or value from config / environment)
+        $rest_proxy = strtolower($App->getConfig('REST_PROXY',null));
+        if ($rest_proxy != 'environment') {
+            curl_setopt($curl, CURLOPT_PROXY, $rest_proxy);
+        }
+
         $App->log('Request URL: '.$request_url."?".$query,4,'Backend');
         if (($response = curl_exec($curl)) === false) {
             $errnum = curl_errno($curl);
@@ -342,7 +352,7 @@ class Backend
         }
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
         if ($httpCode != 200) {
-            $App->log('[Backend/query] HTTP error: '.$httpCode);
+            $App->log('[Backend/query] HTTP ERROR '.$httpCode.', query: "'.$query.'"');
             throw new Exception('ERR_REST_'.$httpCode);
         }
 
