@@ -436,11 +436,22 @@ class Query
      */
     function _tokenize_query($qstring)
     {
+        global $App;
+
         $tokenlist = array();
         while (strlen($qstring)) {
             $qstring = trim($qstring);
             $matches = array();
 
+            if ($App->getConfig('AUTO_ENCLOSE_DASHES',true)) {
+            // match the first 'word - word' without enclosing "..."
+            if (preg_match('/^[^"](\S+\s+[-+]\s+\S+)/',$qstring,$matches)) {
+                array_push($tokenlist,'"'.$matches[0].'"');
+                $qstring = preg_replace('/^(\S+\s+[+-]\s+\S+)/','',$qstring);
+                continue;
+            }
+            }
+
             // ^\S matches "\S, thus check literal in "..." first
             if (preg_match('/^([+-]?"[^"]+")/',$qstring,$matches)) {
                 array_push($tokenlist,$matches[0]);
@@ -454,6 +465,10 @@ class Query
                 continue;
             }
         }
+
+        // escape +- general escaping in -> formatquery():addcslashes
+        $tokenlist = preg_replace('/^([-+])$/','\\\$1',$tokenlist);
+
         return $tokenlist;
     } 
 
